freeport
========================

get available port on your computer
-----------------------------------------

.. image:: https://travis-ci.org/whatArePeopleDownloading/getport.svg?branch=master
    :target: https://travis-ci.org/whatArePeopleDownloading/getport
